@@ -25,6 +25,8 @@ class BaseQueueConf:
     nodes: int = 1
     # name of the job
     name: str = "${hydra.job.name}"
+    # redirect stderr to stdout
+    stderr_to_stdout: bool = False
 
 
 @dataclass
@@ -43,13 +45,16 @@ class SlurmQueueConf(BaseQueueConf):
     #
     # slurm partition to use on the cluster
     partition: Optional[str] = None
+    qos: Optional[str] = None
     comment: Optional[str] = None
     constraint: Optional[str] = None
     exclude: Optional[str] = None
+    gres: Optional[str] = None
     cpus_per_gpu: Optional[int] = None
     gpus_per_task: Optional[int] = None
     mem_per_gpu: Optional[str] = None
     mem_per_cpu: Optional[str] = None
+    account: Optional[str] = None
 
     # Following parameters are submitit specifics
     #
